emacs-orgmode@gnu.org archives
 help / color / mirror / code / Atom feed
From: Ian Barton <lists@manor-farm.org>
To: Sebastian Rose <sebastian_rose@gmx.de>
Cc: emacs-orgmode@gnu.org
Subject: Re: Some Javascript Adventures
Date: Thu, 14 May 2009 13:14:15 +0100	[thread overview]
Message-ID: <4A0C0B17.9060802@manor-farm.org> (raw)
In-Reply-To: <87ab5hqf4p.fsf@kassiopeya.MSHEIMNETZ>

[-- Attachment #1: Type: text/plain, Size: 505 bytes --]


> Unfortunately, it's tricky to get jQuery to work in Opera together with
> org-info.js (org-info.js works, jQuery doesn't :) ).
> Even in Firefox, if you place the jQuery stuff below the org-info.js
> stuff, it stops working.
> 
> We should realy create a jQuery version of org-info.js...
> 
> 
Thanks for the tip about the sitemap. Ihad wondered about trying to 
create a jQuery version, but I need to do a lot more learning first!

Attached is a patch that fixes a mis-spelling in org-info.js.

Ian.


[-- Attachment #2: org-info-src.diff --]
[-- Type: text/x-patch, Size: 2432 bytes --]

diff --git a/code/org-info-js/org-info-src.js b/code/org-info-js/org-info-src.js
index fe73ef1..2e1d4bb 100644
--- a/code/org-info-js/org-info-src.js
+++ b/code/org-info-js/org-info-src.js
@@ -71,7 +71,7 @@ function OrgNode ( _div, _heading, _link, _depth, _parent, _base_id)
   this.link = _link;
   this.hasHighlight = false;              // Node highlighted (search)
   this.parent = _parent;
-  this.durty = false;                     // Node is durty, when children get
+  this.dirty = false;                     // Node is dirty, when children get
                                           // folded seperatly.
   this.state = OrgNode.STATE_FOLDED;
   this.depth = _depth;                    // The Rootelement will have
@@ -250,7 +250,7 @@ OrgNode.prototype.hideAllChildren = function ()
 
 /**
  * This one is called onclick() to toggle the folding state of the node.
  * This one sets it's parent durty, since node is folded individually. Hence the
  * next folding of parent has to collapse all.
  * @param show_childrens_folders Boolean. This is only used for the special way
  * of toggling of the ROOT element. If true, prevents this OrgNode from showing
@@ -259,9 +259,9 @@ OrgNode.prototype.hideAllChildren = function ()
 OrgNode.prototype.fold = function (hide_folder)
 {
   if(this.parent)
-    this.parent.durty = true;
-  if(this.durty) {
-    this.durty = false;
+    this.parent.dirty = true;
+  if(this.dirty) {
+    this.dirty = false;
     this.state = OrgNode.STATE_UNFOLDED; // so next state is FOLDED. See below.
   }
 
@@ -1200,7 +1200,7 @@ var org_html_manager = {
 
   toggleGlobaly: function ()
   {
-    if(this.ROOT.durty) {
+    if(this.ROOT.dirty) {
       this.ROOT.state = OrgNode.STATE_UNFOLDED;
     }
 
@@ -1224,8 +1224,8 @@ var org_html_manager = {
       this.ROOT.state = OrgNode.STATE_UNFOLDED;
     }
 
-    // All this sets ROOT durty again. So clean it:
-    this.ROOT.durty = false;
+    // All this sets ROOT dirty again. So clean it:
+    this.ROOT.dirty = false;
   },
 
 \f
@@ -1793,7 +1793,7 @@ var org_html_manager = {
 
       this.hideConsole();
       if(this.PLAIN_VIEW != this.VIEW) this.plainView();
-      this.ROOT.durty = true;
+      this.ROOT.dirty = true;
       this.toggleGlobaly();
       for(var i = 0; i < this.SECS.length; ++i) {
         OrgNode.showElement(this.SECS[i].div);
@@ -250,7 +250,7 @@ OrgNode.prototype.hideAllChildren = function ()
 /**
  * This one is called onclick() to toggle the folding state of the node.
- * This one sets it's parent durty, since node is folded individually. Hence the
+ * This one sets it's parent dirty, since node is folded individually. Hence the
  * next folding of parent has to collapse all.
  * @param show_childrens_folders Boolean. This is only used for the special way

[-- Attachment #3: Type: text/plain, Size: 204 bytes --]

_______________________________________________
Emacs-orgmode mailing list
Remember: use `Reply All' to send replies to the list.
Emacs-orgmode@gnu.org
http://lists.gnu.org/mailman/listinfo/emacs-orgmode

  reply	other threads:[~2009-05-14 12:14 UTC|newest]

Thread overview: 12+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2009-05-12 11:42 Some Javascript Adventures Ian Barton
2009-05-12 13:48 ` Sebastian Rose
2009-05-12 13:49   ` Carsten Dominik
2009-05-12 15:51     ` Sebastian Rose
2009-05-13 12:07       ` Carsten Dominik
2009-05-12 14:03 ` Sebastian Rose
2009-05-13 13:57   ` Sebastian Rose
2009-05-14 12:14     ` Ian Barton [this message]
2009-05-15 11:17       ` Sebastian Rose
2009-05-14 12:19   ` Ian Barton
2009-05-14 12:30     ` Carsten Dominik
2009-05-14 18:50     ` Sebastian Rose

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://www.orgmode.org/

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=4A0C0B17.9060802@manor-farm.org \
    --to=lists@manor-farm.org \
    --cc=emacs-orgmode@gnu.org \
    --cc=sebastian_rose@gmx.de \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).